@@ -12,6 +12,9 @@
 #include <math.h>
 #include <stdlib.h>
 #include <limits.h>
+#ifdef _DEBUG
+#include <stdio.h>
+#endif
 
 #include "minc2.h"
 #include "minc2_private.h"
@@ -582,7 +585,7 @@ static int mirw_hyperslab_icv(int opcode,
     scaling_needed=0;
   } 
 #ifdef _DEBUG  
-  printf("mirw_hyperslab_icv:Slice_ndim:%d total_number_of_slices:%d image_slice_length:%d scaling_needed:%d\n",slice_ndims,total_number_of_slices,image_slice_length,scaling_needed);
+  printf("mirw_hyperslab_icv:Slice_ndim:%zu total_number_of_slices:%zu image_slice_length:%zu scaling_needed:%zu\n",(size_t)slice_ndims,(size_t)total_number_of_slices,(size_t)image_slice_length,(size_t)scaling_needed);
 #endif
 
   if (opcode == MIRW_OP_READ) 
@@ -949,7 +952,7 @@ static int mirw_hyperslab_normalized(int opcode,
   miget_volume_valid_range( volume, &volume_valid_max, &volume_valid_min);
 
 #ifdef _DEBUG
-  printf("mirw_hyperslab_normalized:Volume:%x valid_max:%f valid_min:%f scaling:%d\n",volume,volume_valid_max,volume_valid_min,volume->has_slice_scaling);
+  printf("mirw_hyperslab_normalized:Volume:%p valid_max:%f valid_min:%f scaling:%d\n",volume,volume_valid_max,volume_valid_min,volume->has_slice_scaling);
 #endif  
   
   if(volume->has_slice_scaling && 
@@ -1044,7 +1047,7 @@ static int mirw_hyperslab_normalized(int opcode,
   }
 
 #ifdef _DEBUG  
-  printf("mirw_hyperslab_normalized:Slice_ndim:%d total_number_of_slices:%d image_slice_length:%d\n",slice_ndims,total_number_of_slices,image_slice_length);
+  printf("mirw_hyperslab_normalized:Slice_ndim:%d total_number_of_slices:%zu image_slice_length:%zu\n",slice_ndims,(size_t)total_number_of_slices,(size_t)image_slice_length);
   printf("mirw_hyperslab_normalized:data min:%f data max:%f buffer_data_type:%d\n",data_min,data_max,buffer_data_type);
 #endif
 
